textgrad.loss
=============

.. automodule:: textgrad.loss

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      ComparisonEvaluation
      ComparisonJsonParsedEvaluation
      ComparisonJsonParsedEvaluationMultiItem
      ComparisonTokenParsedEvaluation
      Loss
      ResponseEvaluation
   
   

   
   
   



